@@ -1,7 +1,9 @@
 package Dist::Zilla::Plugin::InsertCommandOutput;
 
-our $DATE = '2021-02-21'; # DATE
-our $VERSION = '0.053'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-05-21'; # DATE
+our $DIST = 'Dist-Zilla-Plugin-InsertCommandOutput'; # DIST
+our $VERSION = '0.054'; # VERSION
 
 use 5.010001;
 use strict;
@@ -30,7 +32,11 @@ sub munge_files {
 sub munge_file {
     my ($self, $file) = @_;
     my $content_as_bytes = $file->encoded_content;
-    if ($content_as_bytes =~ s{^#\s*COMMAND:\s*(.*)\s*$}{$self->_command_output($1)."\n"}egm) {
+    if ($content_as_bytes =~ s{^#\s*COMMAND:\s*(.*)\s*(\R|\z)}{
+        my $output = $self->_command_output($1);
+        $output .= "\n" unless $output =~ /\R\z/;
+        $output;
+    }egm) {
         $self->log(["inserting output of command '%s' in %s", $1, $file->name]);
         $self->log_debug(["output of command: %s", $content_as_bytes]);
         $file->encoded_content($content_as_bytes);
@@ -66,7 +72,7 @@ Dist::Zilla::Plugin::InsertCommandOutput - Insert the output of command into you
 
 =head1 VERSION
 
-This document describes version 0.053 of Dist::Zilla::Plugin::InsertCommandOutput (from Perl distribution Dist-Zilla-Plugin-InsertCommandOutput), released on 2021-02-21.
+This document describes version 0.054 of Dist::Zilla::Plugin::InsertCommandOutput (from Perl distribution Dist-Zilla-Plugin-InsertCommandOutput), released on 2021-05-21.
 
 =head1 SYNOPSIS
 
